Package: RVIpkg
Title: Regional Vulnerability Index
Version: 0.3.4
Authors@R: c(
    person(given = "Si",
           family = "Gao",
           role = c("aut", "cre","dtc"),
           email = c("iamgaosi@yahoo.com","Si.Gao@uth.tmc.edu"),
           comment = "RVIpkg method development, code development, maintenance, data collection"),
    person(given = "Peter",
           family = "Kochunov",
           role = c("aut","dtc","cph","fnd"),
           email = "peter.kochunov@uth.tmc.edu",
           comment = "RVIpkg concept, method development, data collection and funding"),
    person(given = "Kathryn",
           family = "Hatch",
           role = c("ctb","dtc"),
           email = "khatchal@gmail.com",
           comment = "RVIpkg testing and data collection"),
    person(given = "Yizhou",
           family = "Ma",
           role = c("ctb","dtc"),
           email = "yizhou.ma@uth.tmc.edu",
           comment = "RVIpkg testing, method development and data collection"),
    person(given = "Fatima",
           family = "Talib",
           role = c("ctb"),
           email = "fatal1@umbc.edu",
           comment = "RVIpkg testing and method")
           )
Description: The Regional Vulnerability Index (RVI), a statistical measure of brain structural abnormality, quantifies an individual's similarity to the expected pattern (effect size) of deficits in schizophrenia (Kochunov P, Fan F, Ryan MC, et al. (2020) <doi:10.1002/hbm.25045>).
License: GPL (>= 2)
Encoding: UTF-8
LazyData: true
RoxygenNote: 7.3.3
Depends: R (>= 3.5)
Imports: stats
NeedsCompilation: no
Packaged: 2026-03-27 21:03:14 UTC; x-sgao
Maintainer: Si Gao <iamgaosi@yahoo.com>
Author: Si Gao [aut, cre, dtc] (RVIpkg method development, code development,
    maintenance, data collection),
  Peter Kochunov [aut, dtc, cph, fnd] (RVIpkg concept, method
    development, data collection and funding),
  Kathryn Hatch [ctb, dtc] (RVIpkg testing and data collection),
  Yizhou Ma [ctb, dtc] (RVIpkg testing, method development and data
    collection),
  Fatima Talib [ctb] (RVIpkg testing and method)
Repository: CRAN
Date/Publication: 2026-03-27 21:30:02 UTC
Built: R 4.6.0; ; 2026-04-27 02:36:00 UTC; unix
