#' @title Simulated volumes of subcortical structures
#'
#' @description Simulated volumes of subcortical structures of Schizophrenia spectrum disorder are used as an example for this function.
#' You can calculate RVI for this dataset
#'
#' @format A data frame with 196 rows and 12 variables:
#' \describe{
#'   \item{ID}{subjects' ID}
#'   \item{DX}{indicators of control group}
#'   \item{Age}{subjects' age}
#'   \item{Sex}{subjects' gehder}
#'   \item{Site}{subjects' scanning site}
#'   \item{Lateral.Ventricle}{simulated volumes of lateral Ventricle}
#'   \item{Thalamus}{simulated volumes of Thalamus}
#'   \item{Caudate}{simulated volumes of Caudate}
#'   \item{Putamen}{simulated volumes of Putamen}
#'   \item{Pallidum}{simulated volumes of Pallidum}
#'   \item{Hippocampus}{simulated volumes of Hippocampus}
#'   \item{Amygdala}{simulated volumes of Amygdala}
#'   \item{Left.Accumbens.area}{simulated volumes of left Accumbens}
#' }
#' @source The 'data' dataset is from Maryland Psychiatric Research Center, Department of Psychiatry, University of Maryland School of Medicine.
"data"
